@@ -22,6 +22,10 @@ class UpdateStmt:
     def p_update_where(self, p):
         p.lexer.append('WHERE', p[1])
 
+    @_rule('update_stmt : RRULE')
+    def p_update_rrule(self, p):
+        p.lexer.append('RRULE', p[1])
+
     @_rule('''update_stmts : update_stmt update_stmts
                            | update_stmt''')
     def p_update_stmts(self, p):
